import request from '@/utils/request'

// 查询店铺信息列表
export function listShops(query) {
  return request({
    url: '/shops/shops/list',
    method: 'get',
    params: query
  })
}

// 查询店铺信息详细
export function getShops(shopsId) {
  return request({
    url: '/shops/shops/' + shopsId,
    method: 'get'
  })
}

// 新增店铺信息
export function addShops(data) {
  return request({
    url: '/shops/shops',
    method: 'post',
    data: data
  })
}

// 修改店铺信息
export function updateShops(data) {
  return request({
    url: '/shops/shops',
    method: 'put',
    data: data
  })
}

// 删除店铺信息
export function delShops(shopsId) {
  return request({
    url: '/shops/shops/' + shopsId,
    method: 'delete'
  })
}

// 导出店铺信息
export function exportShops(query) {
  return request({
    url: '/shops/shops/export',
    method: 'get',
    params: query
  })
}


// 批量通过内容
export function handleUpDateOKShops(shopsId,data) {
  return request({
    url: '/shops/shops/okshops/' + shopsId,
    method: 'post',
    data: data
  })
}
